Analysis — GromacsWrapper 0.5.0-dev documentation

# Analysis

The analysis package uses the `gromacs` package and various other third party ones such as numpy and pylab. It provides a framework to analyze Gromacs MD simulations.

- Analysis core modules
  - `gromacs.analysis` – Analysis Package Overview
  - `analysis.core` – Core classes for analysis of Gromacs trajectories
- Support modules
  - `analysis.collections` – Handling of groups of simulation instances
- Analysis plugins
  - Plugins
  - Helper modules